@@ -467,7 +467,8 @@ xfdesktop_file_utils_add_emblems(GdkPixbuf *pix, GList *emblems)
     /* render up to four emblems for sizes from 48 onwards, else up to 2 emblems */
     max_emblems = (pix_height < 48 && pix_width < 48) ? 2 : 4;
 
-    for(iter = emblems, position = 0; iter != NULL && position < max_emblems; iter = iter->next) {
+    for(iter = g_list_last(emblems), position = 0;
+        iter != NULL && position < max_emblems; iter = iter->prev) {
         /* extract the icon from the emblem and load it */
         GIcon *emblem = g_emblem_get_icon(iter->data);
         GtkIconInfo *icon_info = gtk_icon_theme_lookup_by_gicon(itheme,
@@ -503,13 +504,13 @@ xfdesktop_file_utils_add_emblems(GdkPixbuf *pix, GList *emblems)
                     dest_x = 0;
                     dest_y = dest_height;
                     break;
-                case 2: /* upper right */
+                case 2: /* upper left */
+                    dest_x = dest_y = 0;
+                    break;
+                case 3: /* upper right */
                     dest_x = dest_width;
                     dest_y = 0;
                     break;
-                case 3: /* upper left */
-                    dest_x = dest_y = 0;
-                    break;
                 default:
                     g_warning("Invalid emblem position in xfdesktop_file_utils_add_emblems");
             }
@@ -678,11 +679,14 @@ xfdesktop_file_utils_async_cb(DBusGProxy *proxy, GError *error, gpointer userdat
     GtkWindow *parent = GTK_WINDOW(userdata);
 
     if(error != NULL) {
-        xfce_message_dialog(parent,
-                            _("Error"), GTK_STOCK_DIALOG_ERROR,
-                            _("The requested operation could not be completed"),
-                            error->message, GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
-                            NULL);
+        /* ignore dbus timeout error (bug #11283) */
+        if(error->code != DBUS_GERROR_NO_REPLY) {
+            xfce_message_dialog(parent,
+                                _("Error"), GTK_STOCK_DIALOG_ERROR,
+                                _("The requested operation could not be completed"),
+                                error->message, GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
+                                NULL);
+        }
         g_error_free(error);
     }
 }
